from FantasyNameGenerator.Items import *


class TestItems:
    def test_Book(self):
        for _ in range(100):
            assert str(Book()) is not None

        counter = 100
        for name in Book():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_Children(self):
        for _ in range(100):
            assert str(Book.Children()) is not None

        counter = 100
        for name in Book.Children():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_Drama(self):
        for _ in range(100):
            assert str(Book.Drama()) is not None

        counter = 100
        for name in Book.Drama():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_Fiction(self):
        for _ in range(100):
            assert str(Book.Fiction()) is not None

        counter = 100
        for name in Book.Fiction():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_Horror(self):
        for _ in range(100):
            assert str(Book.Horror()) is not None

        counter = 100
        for name in Book.Horror():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_Humor(self):
        for _ in range(100):
            assert str(Book.Humor()) is not None

        counter = 100
        for name in Book.Humor():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_Mystery(self):
        for _ in range(100):
            assert str(Book.Mystery()) is not None

        counter = 100
        for name in Book.Mystery():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_Nonfiction(self):
        for _ in range(100):
            assert str(Book.Nonfiction()) is not None

        counter = 100
        for name in Book.Nonfiction():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_Romance(self):
        for _ in range(100):
            assert str(Book.Romance()) is not None

        counter = 100
        for name in Book.Romance():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_SciFi(self):
        for _ in range(100):
            assert str(Book.SciFi()) is not None

        counter = 100
        for name in Book.SciFi():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_Tome(self):
        for _ in range(100):
            assert str(Book.Tome()) is not None

        counter = 100
        for name in Book.Tome():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_Relic(self):
        for _ in range(100):
            assert str(Relic()) is not None

        counter = 100
        for name in Relic():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_Armor(self):
        for _ in range(100):
            assert str(Relic.Armor()) is not None

        counter = 100
        for name in Relic.Armor():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_Book(self):
        for _ in range(100):
            assert str(Relic.Book()) is not None

        counter = 100
        for name in Relic.Book():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_Potion(self):
        for _ in range(100):
            assert str(Relic.Potion()) is not None

        counter = 100
        for name in Relic.Potion():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_Jewel(self):
        for _ in range(100):
            assert str(Relic.Jewel()) is not None

        counter = 100
        for name in Relic.Jewel():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_Other(self):
        for _ in range(100):
            assert str(Relic.Other()) is not None

        counter = 100
        for name in Relic.Other():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_Weapon(self):
        for _ in range(100):
            assert str(Weapon()) is not None

        counter = 100
        for name in Weapon():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_Axe(self):
        for _ in range(100):
            assert str(Weapon.Axe()) is not None

        counter = 100
        for name in Weapon.Axe():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_Bow(self):
        for _ in range(100):
            assert str(Weapon.Bow()) is not None

        counter = 100
        for name in Weapon.Bow():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_Dagger(self):
        for _ in range(100):
            assert str(Weapon.Dagger()) is not None

        counter = 100
        for name in Weapon.Dagger():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_Hammer(self):
        for _ in range(100):
            assert str(Weapon.Hammer()) is not None

        counter = 100
        for name in Weapon.Hammer():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_Mace(self):
        for _ in range(100):
            assert str(Weapon.Mace()) is not None

        counter = 100
        for name in Weapon.Mace():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_Spear(self):
        for _ in range(100):
            assert str(Weapon.Spear()) is not None

        counter = 100
        for name in Weapon.Spear():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_Sword(self):
        for _ in range(100):
            assert str(Weapon.Sword()) is not None

        counter = 100
        for name in Weapon.Sword():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1



from FantasyNameGenerator.Stores import *


class TestStores:
    def test_Antique(self):
        for _ in range(100):
            assert str(Antique()) is not None

        counter = 100
        for name in Antique():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_Clothes(self):
        for _ in range(100):
            assert str(Clothes()) is not None

        counter = 100
        for name in Clothes():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_Enchanter(self):
        for _ in range(100):
            assert str(Enchanter()) is not None

        counter = 100
        for name in Enchanter():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_Alchemist(self):
        for _ in range(100):
            assert str(Alchemist()) is not None

        counter = 100
        for name in Alchemist():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_Restaurant(self):
        for _ in range(100):
            assert str(Restaurant()) is not None

        counter = 100
        for name in Restaurant():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_Tavern(self):
        for _ in range(100):
            assert str(Restaurant.Tavern()) is not None

        counter = 100
        for name in Restaurant.Tavern():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_Diner(self):
        for _ in range(100):
            assert str(Restaurant.Diner()) is not None

        counter = 100
        for name in Restaurant.Diner():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_French(self):
        for _ in range(100):
            assert str(Restaurant.French()) is not None

        counter = 100
        for name in Restaurant.French():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_Jeweller(self):
        for _ in range(100):
            assert str(Jeweller()) is not None

        counter = 100
        for name in Jeweller():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_Blacksmith(self):
        for _ in range(100):
            assert str(Blacksmith()) is not None

        counter = 100
        for name in Blacksmith():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_General(self):
        for _ in range(100):
            assert str(General()) is not None

        counter = 100
        for name in General():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_Town(self):
        for _ in range(100):
            assert str(Town()) is not None

        counter = 100
        for name in Town():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_Brothel(self):
        for _ in range(100):
            assert str(Brothel()) is not None

        counter = 100
        for name in Brothel():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_Gunsmith(self):
        for _ in range(100):
            assert str(Gunsmith()) is not None

        counter = 100
        for name in Gunsmith():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1

    def test_Guild(self):
        for _ in range(100):
            assert str(Guild()) is not None

        counter = 100
        for name in Guild():
            assert name is not None
            if counter <= 0:
                break
            else:
                counter -= 1
